@@ -46,7 +46,7 @@ namespace XMPP
 			int type() const;
 
 			// for document open
-			QString nsprefix(const QString &s=QString::null) const;
+			QString nsprefix(const QString &s=QString()) const;
 
 			// for document open / close
 			QString namespaceURI() const;
